==> estateplat-common-1.2.4-20220608.092618-1036-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptQlrqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_qlrqk")
public class GxTcJcptQlrqk {
    @Id
    private String ywid;
    private String bjbh;
    private String qlrdh;
    private String qlrfddb;
    private Integer qlrlx;
    private String qlrmc;
    private Integer qlrxh;
    private String qlrzjh;
    private Integer qlrzjzl;
    private Integer qlrzl;
    private String qlrdlrdh;
    private String qlrdlrmc;
    private String qlrdlrzjh;
    private Integer qlrdlrzjzl;
    private Integer ywrxh;
    private Integer ywrzl;
    private Integer ywrlx;
    private String ywrmc;
    private Integer ywrzjzl;
    private String ywrzjh;
    private String ywrdh;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public String getQlrdh() {
        return qlrdh;
    }

    public void setQlrdh(String qlrdh) {
        this.qlrdh = qlrdh;
    }

    public String getQlrfddb() {
        return qlrfddb;
    }

    public void setQlrfddb(String qlrfddb) {
        this.qlrfddb = qlrfddb;
    }

    public Integer getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(Integer qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public Integer getQlrxh() {
        return qlrxh;
    }

    public void setQlrxh(Integer qlrxh) {
        this.qlrxh = qlrxh;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public Integer getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(Integer qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public Integer getQlrzl() {
        return qlrzl;
    }

    public void setQlrzl(Integer qlrzl) {
        this.qlrzl = qlrzl;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public String getQlrdlrmc() {
        return qlrdlrmc;
    }

    public void setQlrdlrmc(String qlrdlrmc) {
        this.qlrdlrmc = qlrdlrmc;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public Integer getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(Integer qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public Integer getYwrxh() {
        return ywrxh;
    }

    public void setYwrxh(Integer ywrxh) {
        this.ywrxh = ywrxh;
    }

    public Integer getYwrzl() {
        return ywrzl;
    }

    public void setYwrzl(Integer ywrzl) {
        this.ywrzl = ywrzl;
    }

    public Integer getYwrlx() {
        return ywrlx;
    }

    public void setYwrlx(Integer ywrlx) {
        this.ywrlx = ywrlx;
    }

    public String getYwrmc() {
        return ywrmc;
    }

    public void setYwrmc(String ywrmc) {
        this.ywrmc = ywrmc;
    }

    public Integer getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(Integer ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getYwrdh() {
        return ywrdh;
    }

    public void setYwrdh(String ywrdh) {
        this.ywrdh = ywrdh;
    }
}

==> estateplat-common-1.2.4-20220611.095919-1037-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptQlrqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_qlrqk")
public class GxTcJcptQlrqk {
    @Id
    private String qlrid;
    private String ywid;
    private String bjbh;
    private String qlrmc;
    private Integer qlrxh;
    private Integer qlrlx;
    private Integer qlrzjzl;
    private String qlrzjh;
    private Integer qlrzl;
    private String qlrdh;
    private String qlrdlrdh;
    private String qlrdlrmc;
    private Integer qlrdlrzjzl;
    private String qlrdlrzjh;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public String getQlrdh() {
        return qlrdh;
    }

    public void setQlrdh(String qlrdh) {
        this.qlrdh = qlrdh;
    }

    public Integer getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(Integer qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public Integer getQlrxh() {
        return qlrxh;
    }

    public void setQlrxh(Integer qlrxh) {
        this.qlrxh = qlrxh;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public Integer getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(Integer qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public Integer getQlrzl() {
        return qlrzl;
    }

    public void setQlrzl(Integer qlrzl) {
        this.qlrzl = qlrzl;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public String getQlrdlrmc() {
        return qlrdlrmc;
    }

    public void setQlrdlrmc(String qlrdlrmc) {
        this.qlrdlrmc = qlrdlrmc;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public Integer getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(Integer qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }
}
